@@ -6,13 +6,11 @@ API_PREFIX = "https://web3api.io/api/v2/"
 HEADERS = {"foo": "bar", "baz": "qux"}
 RESPONSE = {"test": "data"}
 CHAINS = (
-    Chains.AION,
     Chains.BTC,
     Chains.BCH,
     Chains.BSV,
     Chains.ETH,
     Chains.ETH_RINKEBY,
     Chains.LTC,
-    Chains.XLM,
     Chains.ZEC,
 )
