@@ -6,12 +6,10 @@ from enum import Enum
 class Chains(Enum):
     """Blockchains supported by the Amberdata API."""
 
-    AION = 1
-    BTC = 2
-    BCH = 3
-    BSV = 4
-    ETH = 5
-    ETH_RINKEBY = 6
-    LTC = 7
-    XLM = 8
-    ZEC = 9
+    BTC = 1
+    BCH = 2
+    BSV = 3
+    ETH = 4
+    ETH_RINKEBY = 5
+    LTC = 6
+    ZEC = 7
