@@ -1,7 +1,7 @@
 """This module contains the API handler's base class."""
 
 from json.decoder import JSONDecodeError
-from typing import Any, Dict
+from typing import Dict, Union
 
 import requests
 from requests.compat import urljoin
@@ -13,18 +13,15 @@ from web3data.exceptions import APIError, EmptyResponseError
 class BaseHandler:
     """The API handler base class.
 
-    This class defines the basic methods of performing REST API
-    endpoint queries as well as RPC queries, which are implemented
-    across all handler classes to standardize API requests.
+    This class defines the basic methods of performing REST API endpoint queries as well as RPC
+    queries, which are implemented across all handler classes to standardize API requests.
     """
 
     LIMITED = (
-        Chains.AION,
         Chains.BTC,
         Chains.BCH,
         Chains.BSV,
         Chains.LTC,
-        Chains.XLM,
         Chains.ZEC,
     )
 
@@ -41,7 +38,7 @@ class BaseHandler:
         route: str,
         headers: Dict[str, str],
         params: Dict[str, str],
-    ) -> Dict:
+    ) -> Union[Dict, str]:
         """Perform an HTTP GET request on an API REST endpoint.
 
         :param base_url: The API base URL (common prefix)
@@ -53,17 +50,19 @@ class BaseHandler:
         resp = requests.get(
             url=urljoin(base_url, route), headers=headers, params=params
         )
+
         if not resp.content:
             # triggered if the API returns empty response body
             raise EmptyResponseError("The API returned an empty JSON response")
 
+        if params.get("format", "") == "csv":
+            return resp.text
+
         try:
             result = resp.json()
         except JSONDecodeError:
             # triggered e.g. when API returns empty response or XML error message
-            raise APIError(
-                f"Unable to parse API response to JSON: {resp.content}"
-            )
+            raise APIError(f"Unable to parse API response to JSON: {resp.content}")
         if not result:
             # triggered if the API returns empty JSON object response
             raise EmptyResponseError("The API returned an empty JSON response")
