@@ -1,5 +1,6 @@
 """This module contains the address subhandler."""
 
+import warnings
 from typing import Dict
 
 from web3data.chains import Chains
@@ -55,8 +56,9 @@ class MarketHandler(BaseHandler):
         )
 
     def pairs(self, **kwargs) -> Dict:
-        """Retrieves information about supported exchange-pairs.
-        These types of data are supported:
+        """Retrieves information about supported exchange-pairs. These types of
+        data are supported:
+
         - ticker
         - ohlc (open-high-low-close)
         - trade
@@ -137,7 +139,8 @@ class MarketHandler(BaseHandler):
         )
 
     def order_best_bid_historical(self, pair: str, **kwargs) -> Dict:
-        """Retrieves historical best bid and offer information for the specified pair.
+        """Retrieves historical best bid and offer information for the
+        specified pair.
 
         :param pair: The asset pair to look up
         :key exchange: The exchange(s) for which to retrieve order book data.
@@ -156,7 +159,8 @@ class MarketHandler(BaseHandler):
         )
 
     def order_best_bid_latest(self, pair: str, **kwargs) -> Dict:
-        """Retrieves the latest best bid and offer information for the specified pair and exchange.
+        """Retrieves the latest best bid and offer information for the
+        specified pair and exchange.
 
         :param pair: The asset pair to look up
         :key exchange: The exchange(s) for which to retrieve order book data.
@@ -215,8 +219,9 @@ class MarketHandler(BaseHandler):
             params=kwargs,
         )
 
-    def uniswap_liqudity(self, pair: str, **kwargs) -> Dict:
-        """Retrieves the Uniswap-specific ether and token balance pairs over time.
+    def uniswap_liquidity(self, pair: str, **kwargs) -> Dict:
+        """Retrieves the Uniswap-specific ether and token balance pairs over
+        time.
 
         Note: This endpoint returns a max of 6 months of historical data. In order
         to get more than 6 months you must use the startDate & endDate parameters
@@ -229,6 +234,10 @@ class MarketHandler(BaseHandler):
         :key endDate: Filter to liquidity changes before this date (int)
         :return: The API response parsed into a dict
         """
+        warnings.warn(
+            "The Uniswap liquidity endpoint is scheduled for deprecation",
+            PendingDeprecationWarning,
+        )
         return self.raw_query(
             base_url=self.base_url,
             route=f"market/orders/uniswap/{pair}/liquidity",
@@ -237,7 +246,8 @@ class MarketHandler(BaseHandler):
         )
 
     def trade_pairs_historical(self, pair: str, **kwargs) -> Dict:
-        """Retrieves the historical (time series) trade data for the specified pair.
+        """Retrieves the historical (time series) trade data for the specified
+        pair.
 
         Note: This endpoint returns a max of 6 months of historical data. In order to
         get more than 6 months you must use the startDate & endDate parameters to move
@@ -272,7 +282,8 @@ class MarketHandler(BaseHandler):
         )
 
     def ohlcv_pair_historical(self, pair: str, **kwargs) -> Dict:
-        """Retrieves the historical (time series) open-high-low-close for the specified pair.
+        """Retrieves the historical (time series) open-high-low-close for the
+        specified pair.
 
         Note: This endpoint returns a max of 6 months of historical data. In order to get more
         than 6 months you must use the startDate & endDate parameters to move the time frame
@@ -310,7 +321,7 @@ class MarketHandler(BaseHandler):
         """
         return self.raw_query(
             base_url=self.base_url,
-            route=f"market/prices/{pair}/historical",
+            route=f"market/spot/prices/pairs/{pair}/historical",
             headers=self.initial_headers,
             params=kwargs,
         )
@@ -325,7 +336,7 @@ class MarketHandler(BaseHandler):
         """
         return self.raw_query(
             base_url=self.base_url,
-            route=f"market/prices/{pair}/latest",
+            route=f"market/spot/prices/pairs/{pair}/latest",
             headers=self.initial_headers,
             params=kwargs,
         )
@@ -334,7 +345,8 @@ class MarketHandler(BaseHandler):
         """Retrieves the latest VWAP & TWAP price for the specified base.
 
         :param base: The pair's base
-        :key quote: The currency of the pair. Example: if pair is "eth_usd", then quote is "usd" (str)
+        :key quote: The currency of the pair. Example: if pair is "eth_usd",
+            then quote is "usd" (str)
         :key timeFormat: Time format to use for the timestamps
             (Options: milliseconds, ms, iso, iso8611) (str)
         :return: The API response parsed into a dict
@@ -347,10 +359,12 @@ class MarketHandler(BaseHandler):
         )
 
     def ticker_bid_ask_latest(self, pair: str, **kwargs) -> Dict:
-        """Retrieves the latest market ticker Bid/Ask/Mid/Last for the specified pair.
+        """Retrieves the latest market ticker Bid/Ask/Mid/Last for the
+        specified pair.
 
         :param pair: The asset pair to look up
-        :key exchange: The exchange(s) for which to retrieve market tickers. Example: exchange=bitfinex,bitstamp (str)
+        :key exchange: The exchange(s) for which to retrieve market tickers.
+            Example: exchange=bitfinex,bitstamp (str)
         :return: The API response parsed into a dict
         """
         return self.raw_query(
@@ -361,7 +375,8 @@ class MarketHandler(BaseHandler):
         )
 
     def ticker_bid_ask_historical(self, pair: str, **kwargs) -> Dict:
-        """Retrieves the historical ticker, bid/ask/mid/last, for the specified pair.
+        """Retrieves the historical ticker, bid/ask/mid/last, for the specified
+        pair.
 
         Note: This endpoint returns a max of 6 months of historical data. In order to get more
         than 6 months you must use the startDate & endDate parameters to move the time frame
@@ -407,7 +422,8 @@ class MarketHandler(BaseHandler):
         )
 
     def token_price_latest(self, address: str, **kwargs) -> Dict:
-        """Retrieves the latest price (and other market information) for the specified token.
+        """Retrieves the latest price (and other market information) for the
+        specified token.
 
         :param address: The token's smart contract address
         :key currency: The additional currency (other than ETH and USD)
@@ -422,7 +438,8 @@ class MarketHandler(BaseHandler):
         )
 
     def token_rankings_historical(self, **kwargs) -> Dict:
-        """Retrieves the top ranked tokens by a specific metric, with a lookback window.
+        """Retrieves the top ranked tokens by a specific metric, with a
+        lookback window.
 
         Useful for viewing token trends.
 
